<?php
/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */

namespace Icinga\Data\Filter;

use Icinga\Exception\IcingaException;

/**
 * Filter Exception Class
 *
 * Filter Exceptions should be thrown on filter parse errors or similar
 */
class FilterException extends IcingaException
{
}
